summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--cc/scheduler/scheduler.cc4
-rw-r--r--cc/scheduler/scheduler.h2
-rw-r--r--cc/scheduler/scheduler_state_machine.cc8
-rw-r--r--cc/scheduler/scheduler_state_machine.h2
-rw-r--r--cc/scheduler/scheduler_state_machine_unittest.cc12
-rw-r--r--cc/scheduler/scheduler_unittest.cc12
-rw-r--r--cc/trees/proxy_timing_history.cc2
-rw-r--r--cc/trees/proxy_timing_history.h2
-rw-r--r--cc/trees/thread_proxy.cc10
-rw-r--r--cc/trees/thread_proxy.h2
10 files changed, 26 insertions, 30 deletions
diff --git a/cc/scheduler/scheduler.cc b/cc/scheduler/scheduler.cc
index 4a682cd..52e0f9e 100644
--- a/cc/scheduler/scheduler.cc
+++ b/cc/scheduler/scheduler.cc
@@ -645,8 +645,8 @@ void Scheduler::ProcessScheduledActions() {
case SchedulerStateMachine::ACTION_UPDATE_VISIBLE_TILES:
client_->ScheduledActionUpdateVisibleTiles();
break;
- case SchedulerStateMachine::ACTION_ACTIVATE_PENDING_TREE:
- client_->ScheduledActionActivatePendingTree();
+ case SchedulerStateMachine::ACTION_ACTIVATE_SYNC_TREE:
+ client_->ScheduledActionActivateSyncTree();
break;
case SchedulerStateMachine::ACTION_DRAW_AND_SWAP_IF_POSSIBLE:
DrawAndSwapIfPossible();
diff --git a/cc/scheduler/scheduler.h b/cc/scheduler/scheduler.h
index 3de06ac..3653c30 100644
--- a/cc/scheduler/scheduler.h
+++ b/cc/scheduler/scheduler.h
@@ -35,7 +35,7 @@ class SchedulerClient {
virtual void ScheduledActionAnimate() = 0;
virtual void ScheduledActionCommit() = 0;
virtual void ScheduledActionUpdateVisibleTiles() = 0;
- virtual void ScheduledActionActivatePendingTree() = 0;
+ virtual void ScheduledActionActivateSyncTree() = 0;
virtual void ScheduledActionBeginOutputSurfaceCreation() = 0;
virtual void ScheduledActionManageTiles() = 0;
virtual void DidAnticipatedDrawTimeChange(base::TimeTicks time) = 0;
diff --git a/cc/scheduler/scheduler_state_machine.cc b/cc/scheduler/scheduler_state_machine.cc
index dea25b40..7070c7a 100644
--- a/cc/scheduler/scheduler_state_machine.cc
+++ b/cc/scheduler/scheduler_state_machine.cc
@@ -130,8 +130,8 @@ const char* SchedulerStateMachine::ActionToString(Action action) {
return "ACTION_COMMIT";
case ACTION_UPDATE_VISIBLE_TILES:
return "ACTION_UPDATE_VISIBLE_TILES";
- case ACTION_ACTIVATE_PENDING_TREE:
- return "ACTION_ACTIVATE_PENDING_TREE";
+ case ACTION_ACTIVATE_SYNC_TREE:
+ return "ACTION_ACTIVATE_SYNC_TREE";
case ACTION_DRAW_AND_SWAP_IF_POSSIBLE:
return "ACTION_DRAW_AND_SWAP_IF_POSSIBLE";
case ACTION_DRAW_AND_SWAP_FORCED:
@@ -515,7 +515,7 @@ SchedulerStateMachine::Action SchedulerStateMachine::NextAction() const {
if (ShouldUpdateVisibleTiles())
return ACTION_UPDATE_VISIBLE_TILES;
if (ShouldActivatePendingTree())
- return ACTION_ACTIVATE_PENDING_TREE;
+ return ACTION_ACTIVATE_SYNC_TREE;
if (ShouldCommit())
return ACTION_COMMIT;
if (ShouldAnimate())
@@ -547,7 +547,7 @@ void SchedulerStateMachine::UpdateState(Action action) {
current_frame_number_;
return;
- case ACTION_ACTIVATE_PENDING_TREE:
+ case ACTION_ACTIVATE_SYNC_TREE:
UpdateStateOnActivation();
return;
diff --git a/cc/scheduler/scheduler_state_machine.h b/cc/scheduler/scheduler_state_machine.h
index a2a8b59..0fbdf41 100644
--- a/cc/scheduler/scheduler_state_machine.h
+++ b/cc/scheduler/scheduler_state_machine.h
@@ -93,7 +93,7 @@ class CC_EXPORT SchedulerStateMachine {
ACTION_SEND_BEGIN_MAIN_FRAME,
ACTION_COMMIT,
ACTION_UPDATE_VISIBLE_TILES,
- ACTION_ACTIVATE_PENDING_TREE,
+ ACTION_ACTIVATE_SYNC_TREE,
ACTION_DRAW_AND_SWAP_IF_POSSIBLE,
ACTION_DRAW_AND_SWAP_FORCED,
ACTION_DRAW_AND_SWAP_ABORT,
diff --git a/cc/scheduler/scheduler_state_machine_unittest.cc b/cc/scheduler/scheduler_state_machine_unittest.cc
index b583424..c89da2f 100644
--- a/cc/scheduler/scheduler_state_machine_unittest.cc
+++ b/cc/scheduler/scheduler_state_machine_unittest.cc
@@ -232,8 +232,7 @@ TEST(SchedulerStateMachineTest, MainFrameBeforeDrawDisabled) {
state.OnBeginImplFrame(CreateBeginFrameArgsForTesting());
state.NotifyReadyToActivate();
- EXPECT_ACTION_UPDATE_STATE(
- SchedulerStateMachine::ACTION_ACTIVATE_PENDING_TREE);
+ EXPECT_ACTION_UPDATE_STATE(SchedulerStateMachine::ACTION_ACTIVATE_SYNC_TREE);
EXPECT_ACTION_UPDATE_STATE(SchedulerStateMachine::ACTION_ANIMATE);
EXPECT_ACTION_UPDATE_STATE(SchedulerStateMachine::ACTION_NONE);
EXPECT_EQ(state.CommitState(),
@@ -308,8 +307,7 @@ TEST(SchedulerStateMachineTest, MainFrameBeforeActivationEnabled) {
// Verify NotifyReadyToActivate unblocks activation, draw, and
// commit in that order.
state.NotifyReadyToActivate();
- EXPECT_ACTION_UPDATE_STATE(
- SchedulerStateMachine::ACTION_ACTIVATE_PENDING_TREE);
+ EXPECT_ACTION_UPDATE_STATE(SchedulerStateMachine::ACTION_ACTIVATE_SYNC_TREE);
EXPECT_ACTION_UPDATE_STATE(SchedulerStateMachine::ACTION_NONE);
EXPECT_TRUE(state.ShouldTriggerBeginImplFrameDeadlineEarly());
@@ -1595,8 +1593,7 @@ TEST(SchedulerStateMachineTest,
EXPECT_ACTION_UPDATE_STATE(SchedulerStateMachine::ACTION_COMMIT);
EXPECT_TRUE(state.PendingActivationsShouldBeForced());
- EXPECT_ACTION_UPDATE_STATE(
- SchedulerStateMachine::ACTION_ACTIVATE_PENDING_TREE);
+ EXPECT_ACTION_UPDATE_STATE(SchedulerStateMachine::ACTION_ACTIVATE_SYNC_TREE);
EXPECT_TRUE(state.PendingDrawsShouldBeAborted());
EXPECT_ACTION_UPDATE_STATE(SchedulerStateMachine::ACTION_DRAW_AND_SWAP_ABORT);
@@ -1733,8 +1730,7 @@ void FinishPreviousCommitAndDrawWithoutExitingDeadline(
EXPECT_ACTION_UPDATE_STATE(SchedulerStateMachine::ACTION_COMMIT);
EXPECT_ACTION_UPDATE_STATE(SchedulerStateMachine::ACTION_NONE);
state.NotifyReadyToActivate();
- EXPECT_ACTION_UPDATE_STATE(
- SchedulerStateMachine::ACTION_ACTIVATE_PENDING_TREE);
+ EXPECT_ACTION_UPDATE_STATE(SchedulerStateMachine::ACTION_ACTIVATE_SYNC_TREE);
EXPECT_ACTION_UPDATE_STATE(SchedulerStateMachine::ACTION_NONE);
state.OnBeginImplFrame(CreateBeginFrameArgsForTesting());
diff --git a/cc/trees/proxy_timing_history.cc b/cc/trees/proxy_timing_history.cc
index e920f28..6c45f71 100644
--- a/cc/trees/proxy_timing_history.cc
+++ b/cc/trees/proxy_timing_history.cc
@@ -47,7 +47,7 @@ void ProxyTimingHistory::DidCommit() {
commit_complete_time_ - begin_main_frame_sent_time_);
}
-void ProxyTimingHistory::DidActivatePendingTree() {
+void ProxyTimingHistory::DidActivateSyncTree() {
commit_to_activate_duration_history_.InsertSample(
base::TimeTicks::HighResNow() - commit_complete_time_);
}
diff --git a/cc/trees/proxy_timing_history.h b/cc/trees/proxy_timing_history.h
index 01a92d9..9230e8a 100644
--- a/cc/trees/proxy_timing_history.h
+++ b/cc/trees/proxy_timing_history.h
@@ -20,7 +20,7 @@ class ProxyTimingHistory {
void DidBeginMainFrame();
void DidCommit();
- void DidActivatePendingTree();
+ void DidActivateSyncTree();
void DidStartDrawing();
// Returns draw duration.
base::TimeDelta DidFinishDrawing();
diff --git a/cc/trees/thread_proxy.h b/cc/trees/thread_proxy.h
index 74accef..289ea80 100644
--- a/cc/trees/thread_proxy.h
+++ b/cc/trees/thread_proxy.h
@@ -216,7 +216,7 @@ class CC_EXPORT ThreadProxy : public Proxy,
virtual void ScheduledActionAnimate() OVERRIDE;
virtual void ScheduledActionCommit() OVERRIDE;
virtual void ScheduledActionUpdateVisibleTiles() OVERRIDE;
- virtual void ScheduledActionActivatePendingTree() OVERRIDE;
+ virtual void ScheduledActionActivateSyncTree() OVERRIDE;
virtual void ScheduledActionBeginOutputSurfaceCreation() OVERRIDE;
virtual void ScheduledActionManageTiles() OVERRIDE;
virtual void DidAnticipatedDrawTimeChange(base::TimeTicks time) OVERRIDE;
diff --git a/cc/scheduler/scheduler_unittest.cc b/cc/scheduler/scheduler_unittest.cc
index 19ba524..aa61af7 100644
--- a/cc/scheduler/scheduler_unittest.cc
+++ b/cc/scheduler/scheduler_unittest.cc
@@ -199,8 +199,8 @@ class FakeSchedulerClient : public SchedulerClient {
if (redraw_will_happen_if_update_visible_tiles_happens_)
scheduler_->SetNeedsRedraw();
}
- virtual void ScheduledActionActivatePendingTree() OVERRIDE {
- actions_.push_back("ScheduledActionActivatePendingTree");
+ virtual void ScheduledActionActivateSyncTree() OVERRIDE {
+ actions_.push_back("ScheduledActionActivateSyncTree");
states_.push_back(scheduler_->AsValue().release());
}
virtual void ScheduledActionBeginOutputSurfaceCreation() OVERRIDE {
@@ -966,7 +966,7 @@ TEST(SchedulerTest, ShouldUpdateVisibleTiles) {
client.Reset();
scheduler->NotifyReadyToActivate();
- EXPECT_SINGLE_ACTION("ScheduledActionActivatePendingTree", client);
+ EXPECT_SINGLE_ACTION("ScheduledActionActivateSyncTree", client);
client.Reset();
client.SetSwapContainsIncompleteTile(true);
@@ -1641,7 +1641,7 @@ void DidLoseOutputSurfaceAfterBeginFrameStartedWithHighLatency(
scheduler->NotifyReadyToCommit();
if (impl_side_painting) {
EXPECT_ACTION("ScheduledActionCommit", client, 0, 3);
- EXPECT_ACTION("ScheduledActionActivatePendingTree", client, 1, 3);
+ EXPECT_ACTION("ScheduledActionActivateSyncTree", client, 1, 3);
EXPECT_ACTION("ScheduledActionBeginOutputSurfaceCreation", client, 2, 3);
} else {
EXPECT_ACTION("ScheduledActionCommit", client, 0, 2);
@@ -1691,8 +1691,8 @@ void DidLoseOutputSurfaceAfterReadyToCommit(bool impl_side_painting) {
client.Reset();
scheduler->DidLoseOutputSurface();
if (impl_side_painting) {
- // Pending tree should be forced to activate.
- EXPECT_SINGLE_ACTION("ScheduledActionActivatePendingTree", client);
+ // Sync tree should be forced to activate.
+ EXPECT_SINGLE_ACTION("ScheduledActionActivateSyncTree", client);
} else {
// Do nothing when impl frame is in deadine pending state.
EXPECT_NO_ACTION(client);
diff --git a/cc/trees/thread_proxy.cc b/cc/trees/thread_proxy.cc
index 56ce577..b5ccc38 100644
--- a/cc/trees/thread_proxy.cc
+++ b/cc/trees/thread_proxy.cc
@@ -988,8 +988,8 @@ void ThreadProxy::ScheduledActionCommit() {
if (hold_commit) {
// For some layer types in impl-side painting, the commit is held until
// the pending tree is activated. It's also possible that the
// pending tree has already activated if there was no work to be done.
TRACE_EVENT_INSTANT0("cc", "HoldCommit", TRACE_EVENT_SCOPE_THREAD);
impl().completion_event_for_commit_held_on_tree_activation =
impl().commit_completion_event;
@@ -1018,8 +1018,8 @@ void ThreadProxy::ScheduledActionUpdateVisibleTiles() {
impl().layer_tree_host_impl->UpdateVisibleTiles();
}
-void ThreadProxy::ScheduledActionActivatePendingTree() {
- TRACE_EVENT0("cc", "ThreadProxy::ScheduledActionActivatePendingTree");
+void ThreadProxy::ScheduledActionActivateSyncTree() {
+ TRACE_EVENT0("cc", "ThreadProxy::ScheduledActionActivateSyncTree");
DCHECK(IsImplThread());
impl().layer_tree_host_impl->ActivateSyncTree();
}
@@ -1437,7 +1437,7 @@ void ThreadProxy::DidActivateSyncTree() {
UpdateBackgroundAnimateTicking();
- impl().timing_history.DidActivatePendingTree();
+ impl().timing_history.DidActivateSyncTree();
}
void ThreadProxy::DidManageTiles() {
@@ -988,8 +988,8 @@ void ThreadProxy::ScheduledActionCommit() {
if (hold_commit) {
// For some layer types in impl-side painting, the commit is held until
- // the pending tree is activated. It's also possible that the
- // pending tree has already activated if there was no work to be done.
+ // the sync tree is activated. It's also possible that the
+ // sync tree has already activated if there was no work to be done.
TRACE_EVENT_INSTANT0("cc", "HoldCommit", TRACE_EVENT_SCOPE_THREAD);
impl().completion_event_for_commit_held_on_tree_activation =